@@ -25,6 +25,7 @@
 #include <utility.h>
 #include <gui/dialogfilechooser.h>
 #include <vector>
+#include <subtitleformatsystem.h>
 
 /*
  *
@@ -130,9 +131,9 @@ public:
 		// recent files
 		Glib::RefPtr<Gtk::RecentAction> recentAction = Gtk::RecentAction::create("menu-recent-open-document", _("Open _Recent"));
 
-		Gtk::RecentFilter filter;
-		filter.set_name("subtitleeditor");
-		filter.add_group("subtitleeditor");
+		Glib::RefPtr<Gtk::RecentFilter> filter = Gtk::RecentFilter::create();
+		filter->set_name("subtitleeditor");
+		filter->add_group("subtitleeditor");
 		recentAction->set_filter(filter);
 
 		recentAction->set_show_icons(false);
@@ -245,7 +246,8 @@ protected:
 
 		g_return_if_fail(doc);
 
-		doc->setFilename(DocumentSystem::getInstance().create_untitled_name());
+		Glib::ustring ext = SubtitleFormatSystem::instance().get_extension_of_format(doc->getFormat());
+		doc->setFilename(DocumentSystem::getInstance().create_untitled_name(ext));
 
 		DocumentSystem::getInstance().append(doc);
 	}
@@ -284,9 +286,9 @@ protected:
 
 		Glib::ustring charset = dialog->get_encoding();
 
-		std::list<Glib::ustring> uris = dialog->get_uris();
+		std::vector<Glib::ustring> uris = dialog->get_uris();
 
-		for(std::list<Glib::ustring>::const_iterator it=uris.begin();
+		for(std::vector<Glib::ustring>::const_iterator it=uris.begin();
 				it != uris.end(); ++it)
 		{
 			open_document(*it, charset);
@@ -366,15 +368,26 @@ protected:
 
 		g_return_val_if_fail(doc, false);
 
+		Glib::ustring format = default_format.empty() ? doc->getFormat() : default_format;
+
 		DialogSaveDocument::auto_ptr dialog = DialogSaveDocument::create();
 
 		if(Glib::file_test(doc->getFilename(), Glib::FILE_TEST_EXISTS))
-			dialog->set_filename(doc->getFilename());
+		{
+			dialog->set_current_folder_and_name(doc->getFilename());
+		}
+		else if(SubtitleEditorWindow::get_instance()->get_player()->get_state() != Player::NONE)
+		{
+			dialog->set_filename_from_another_uri(
+				SubtitleEditorWindow::get_instance()->get_player()->get_uri(),
+				SubtitleFormatSystem::instance().get_extension_of_format(format));
+		}
 		else
+		{
 			dialog->set_current_name(doc->getName());
+		}
 
-		dialog->set_format(
-				default_format.empty() ? doc->getFormat() : default_format);
+		dialog->set_format(format);
 		dialog->set_encoding(doc->getCharset());
 		dialog->set_newline(doc->getNewLine());
 		dialog->set_do_overwrite_confirmation(true);
@@ -388,7 +401,7 @@ protected:
 
 		Glib::ustring filename = dialog->get_filename();
 		Glib::ustring uri = dialog->get_uri();
-		Glib::ustring format = dialog->get_format();
+		format = dialog->get_format();
 		Glib::ustring encoding = dialog->get_encoding();
 		Glib::ustring newline = dialog->get_newline();
 
@@ -733,9 +746,9 @@ protected:
 
 		m_autosave_timeout.disconnect();
 
-		bool used_autosave = Config::getInstance().get_value_bool("interface", "used-autosave");
-		if(used_autosave == false)
+		if(Config::getInstance().get_value_bool("interface", "used-autosave") == false)
 			return;
+
 		int autosave_minutes = Config::getInstance().get_value_int("interface", "autosave-minutes");
 
 		long mseconds = SubtitleTime(0, autosave_minutes, 0, 0).totalmsecs;
