@@ -27,7 +27,9 @@
 #include <gtkmm_utility.h>
 #include <widget_config_utility.h>
 #include <glib.h>
+#include <gui/comboboxtextcolumns.h>
 
+// FIXME: gtkmm3
 /*
  * FIXME:
  *	Subtitle selected changed caused by no modal window (find)
@@ -48,6 +50,7 @@ public:
 	void reset()
 	{
 		text = Glib::ustring();
+		replacement = Glib::ustring();
 		column = 0;
 		found = false;
 		start = len = Glib::ustring::npos;
@@ -56,6 +59,7 @@ public:
 public:
 	int column;
 	Glib::ustring text;
+	Glib::ustring replacement;
 	bool found;
 	Glib::ustring::size_type start;
 	Glib::ustring::size_type len;
@@ -136,7 +140,7 @@ public:
 	}
 
 	/*
-	 * Return the current remplacement text.
+	 * Return the current replacement text.
 	 */
 	Glib::ustring get_replacement()
 	{
@@ -182,7 +186,7 @@ public:
 	}
 
 	/*
-	 * Replace the current search (MatchInfo) by the remplacement text.
+	 * Replace the current search (MatchInfo) by the replacement text.
 	 */
 	bool replace(Document &doc, Subtitle &sub, MatchInfo &info)
 	{
@@ -193,12 +197,11 @@ public:
 				(info.start == Glib::ustring::npos && info.len == Glib::ustring::npos))
 			return false;
 
-		Glib::ustring text = info.text;
-
-		if(text.empty())
+		if(info.text.empty())
 			return false;
 
-		Glib::ustring replacement = get_replacement();
+		Glib::ustring text = info.text;
+		Glib::ustring replacement = info.replacement;
 
 		try
 		{
@@ -248,6 +251,8 @@ protected:
 			if(beginning != Glib::ustring::npos)
 				text = text.substr(beginning, text.size());
 
+      if(info)
+			  info->replacement = get_replacement();
 			if(!find(get_pattern(), get_pattern_options(), text, info))
 				return false;
 
@@ -278,7 +283,7 @@ protected:
 
 		if(pattern_options & USE_REGEX) // Search with regular expression
 		{
-			found = regex_exec(pattern, text, (pattern_options & IGNORE_CASE), start, len);
+			found = regex_exec(pattern, text, (pattern_options & IGNORE_CASE), start, len, info->replacement);
 		}
 		else // Without regular expression
 		{
@@ -307,12 +312,13 @@ protected:
 	 * FIXME: Remove Me
 	 * Waiting the Glib::MatchInfo API in glibmm.
 	 */
-	bool regex_exec(const Glib::ustring &pattern, const Glib::ustring &string, bool caseless, Glib::ustring::size_type &start, Glib::ustring::size_type &len)
+	bool regex_exec(const Glib::ustring &pattern, const Glib::ustring &string, bool caseless, Glib::ustring::size_type &start, Glib::ustring::size_type &len, Glib::ustring &replacement)
 	{
 		bool found = false;
 		GRegex *regex = NULL;
 		GMatchInfo *match_info = NULL;
 		GError *error = NULL;
+		gboolean references = FALSE;
 
 		int compile_flags = (GRegexMatchFlags)0;
 		if(caseless)
@@ -345,6 +351,12 @@ protected:
 					len = end_pos - start_pos;
 					found = true;
 				}
+
+				// Expand any references in the replacement string
+				references = TRUE;
+				g_regex_check_replacement(replacement.c_str(), &references, &error);
+				if(error == NULL && references)
+					replacement = g_match_info_expand_references(match_info, replacement.c_str(), &error);
 			}
 		}
 		g_match_info_free(match_info);
@@ -357,11 +369,11 @@ protected:
 
 /*
  */
-class ComboBoxEntryHistory : public Gtk::ComboBoxEntryText
+class ComboBoxEntryHistory : public Gtk::ComboBoxText
 {
 public:
-	ComboBoxEntryHistory(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>& xml)
-	:Gtk::ComboBoxEntryText(cobject)
+	ComboBoxEntryHistory(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builder>&)
+	:Gtk::ComboBoxText(cobject)
 	{
 	}
 
@@ -386,7 +398,7 @@ public:
 		if(!text.empty())
 		{
 			remove_item(text);
-			prepend_text(text);
+			prepend(text);
 			clamp_items();
 		}
 	}
@@ -407,7 +419,7 @@ public:
 		for(it = keys.begin(); it != keys.end(); ++it)
 		{
 			if(re->match(*it))
-				append_text(cfg.get_value_string(m_group, *it));
+				append(cfg.get_value_string(m_group, *it));
 		}
 		get_entry()->set_text(cfg.get_value_string(m_group, m_key));
 	}
@@ -427,10 +439,9 @@ public:
 	 */
 	bool save_iter(const Gtk::TreePath &path, const Gtk::TreeIter &it)
 	{
-		TextModelColumns cols;
 		Config::getInstance().set_value_string(	m_group,
 				Glib::ustring::compose("%1-%2", m_key, path.to_string()), // key-id
-				(*it)[cols.m_column]); // text
+				(*it)[m_cols.m_col_name]); // text
 		return false;
 	}
 
@@ -439,13 +450,12 @@ public:
 	 */
 	void remove_item(const Glib::ustring &text)
 	{
-		TextModelColumns cols;
 		Glib::RefPtr<Gtk::ListStore> model = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(get_model());
 
 		Gtk::TreeIter it = model->children().begin();
 		while(it)
 		{
-			if((*it)[cols.m_column] == text)
+			if((*it)[m_cols.m_col_name] == text)
 				it = model->erase(it);
 			else
 				++it;
@@ -469,6 +479,7 @@ public:
 protected:
 	Glib::ustring m_group;
 	Glib::ustring m_key;
+	ComboBoxTextColumns m_cols;
 };
 
 /*
@@ -565,6 +576,9 @@ public:
 	 */
 	void init_with_document(Document *doc)
 	{
+		if(m_connection_subtitle_deleted)
+			m_connection_subtitle_deleted.disconnect();
+
 		m_document = doc;
 		bool has_doc = (doc != NULL);
 		// Update the sensitivity of widgets
@@ -595,6 +609,9 @@ public:
 				m_subtitle = subtitles.get_first();
 			update_search_ui();
 		}
+
+		m_connection_subtitle_deleted = doc->get_signal("subtitle-deleted").connect(
+			sigc::mem_fun(*this, &DialogFindAndReplace::on_subtitle_deleted));
 	}
 
 	/*
@@ -611,6 +628,23 @@ public:
 		}
 	}
 
+	/*
+	 */
+	void on_subtitle_deleted()
+	{
+		// Reset values
+		m_subtitle = Subtitle();
+		m_info.reset();
+
+		Subtitles subtitles = m_document->subtitles();
+		if(subtitles.size() > 0)
+		{
+			m_subtitle = subtitles.get_first_selected();
+			if(!m_subtitle)
+				m_subtitle = subtitles.get_first();
+		}
+		update_search_ui();
+	}
 	/*
 	 * Update the label of the current column and sets the sensitivity.
 	 */
@@ -700,6 +734,7 @@ public:
 		{
 			m_comboboxPattern->save_history();
 			m_comboboxReplacement->save_history();
+			m_connection_subtitle_deleted.disconnect();
 
 			delete m_instance;
 			m_instance = NULL;
@@ -852,6 +887,8 @@ protected:
 	Gtk::CheckButton* m_checkColumnText;
 	Gtk::CheckButton* m_checkColumnTranslation;
 
+	sigc::connection m_connection_subtitle_deleted;
+
 	static DialogFindAndReplace* m_instance;
 };
 
@@ -1008,54 +1045,66 @@ protected:
 			return;
 		}
 
-		// try to start the search from the subtitle selected
-		Subtitle sub = subtitles.get_first_selected();
-
-		if(sub)
-		{
-			// Start from the previous/next subtitle
-			sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
-			while(sub)
-			{
-				if(FaR::instance().find_in_subtitle(sub, NULL))
-					break;	// found
-				sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
-			}
-
-			// if not found search again from the last
-			if(!sub)
-			{
-				sub = (backwards) ? subtitles.get_last() : subtitles.get_first();
-				while(sub)
-				{
-					if(FaR::instance().find_in_subtitle(sub, NULL))
-						break;
-					sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
-				}
-			}
-		}
-		else // start the search from the beginning/last
-		{
-			sub = (backwards) ? subtitles.get_last() : subtitles.get_first();
-			while(sub)
-			{
-				if(FaR::instance().find_in_subtitle(sub, NULL))
-					break;
-				sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
-			}
-		}
-
-		if(sub)	// found
-		{
-			doc->subtitles().select(sub);
-		}
-		else	// not found
-		{
-			doc->subtitles().unselect_all();
-			doc->flash_message(_("Not found"));
-		}
+    Subtitle sub;
+    if(search_from_current_position(sub, backwards) || search_from_beginning(sub, backwards))
+    {
+      subtitles.select(sub);
+    }
+    else
+    {
+      subtitles.unselect_all();
+      doc->flash_message(_("Not found"));
+    }
 	}
 
+  /*
+   * Start the search from the previous/next subtitle
+   */
+  bool search_from_current_position(Subtitle &res, bool backwards)
+  {
+    se_debug(SE_DEBUG_PLUGINS);
+
+    Subtitles subtitles = get_current_document()->subtitles();
+
+    Subtitle sub = subtitles.get_first_selected();
+    // selection empty? return invalid subtitle
+    if(!sub)
+      return false;
+ 
+    // Start from the previous/next subtitle
+    sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
+    while(sub)
+    {
+      if(FaR::instance().find_in_subtitle(sub, NULL))
+      {
+        res = sub;
+        return true;
+      }
+      sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
+    }
+    return false;
+  }
+
+  /*
+   */
+  bool search_from_beginning(Subtitle &res, bool backwards)
+  {
+    se_debug(SE_DEBUG_PLUGINS);
+ 
+    Subtitles subtitles = get_current_document()->subtitles();
+    Subtitle sub = (backwards) ? subtitles.get_last() : subtitles.get_first();
+    while(sub)
+    {
+      if(FaR::instance().find_in_subtitle(sub, NULL))
+      {
+        res = sub;
+        return true;
+      }
+      sub = (backwards) ? subtitles.get_previous(sub) : subtitles.get_next(sub);
+    }
+    return false;
+  }
+
 protected:
 	Gtk::UIManager::ui_merge_id ui_id;
 	Glib::RefPtr<Gtk::ActionGroup> action_group;
