@@ -4,7 +4,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2012, kitone
+ *	Copyright @ 2005-2015, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -337,9 +337,9 @@ public:
 		// Recent files
 		Glib::RefPtr<Gtk::RecentAction> recentAction = Gtk::RecentAction::create("video-player/recent-files", _("_Recent Files"));
 
-		Gtk::RecentFilter filter;
-		filter.set_name("subtitleeditor");
-		filter.add_group("subtitleeditor-video-player");
+		Glib::RefPtr<Gtk::RecentFilter> filter = Gtk::RecentFilter::create();
+		filter->set_name("subtitleeditor");
+		filter->add_group("subtitleeditor-video-player");
 		recentAction->set_filter(filter);
 		recentAction->set_show_icons(false);
 		recentAction->set_show_numbers(true);
@@ -508,7 +508,10 @@ public:
 			if(msg == Player::STATE_NONE)
 				remove_menu_audio_track();
 			else if(msg == Player::STREAM_READY)
+			{
 				build_menu_audio_track();
+				add_in_recent_manager(player()->get_uri());
+			}
 			update_ui();
 			// If need, ask to display the video player
 			if(msg == Player::STREAM_READY)
