@@ -4,7 +4,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2009, kitone
+ *	Copyright @ 2005-2010, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -39,9 +39,8 @@ static Glib::Timer profiling_timer;
 static double profiling_timer_last = 0.0;
 
 /*
- *
  */
-void se_debug_init(int flags)
+void __se_debug_init(int flags)
 {
 	debug_flags = flags;
 
@@ -53,7 +52,6 @@ void se_debug_init(int flags)
 }
 
 /*
- *	simple teste avec le flags
  */
 bool se_debug_check_flags(int flag)
 {
