@@ -23,7 +23,7 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <glibmm/ustring.h>
+#include <glibmm.h>
 #include <map>
 
 /*
