@@ -7,7 +7,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2010, kitone
+ *	Copyright @ 2005-2014, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -65,7 +65,7 @@ public:
 	/*
 	 * Constructor by copy
 	 */
-	Document(Document &copy, int copy_subtitles );
+	Document(Document &copy, bool copy_subtitles );
 
 	/*
 	 * Destructor
@@ -271,7 +271,7 @@ public:
 	FRAMERATE get_framerate();
 
 	/*
-	 * Return a signal connector from his name.
+	 * Return a signal connector from its name.
 	 *
 	 * The list of signals available:
 	 *
@@ -281,6 +281,10 @@ public:
 	 *		the selection of subtitle changed.
 	 * "subtitle-time-changed"
 	 *		time of subtitle(s) changed.
+	 * "subtitle-deleted"
+	 *		one or more subtitles have been removed.
+	 * "subtitle-insered"
+	 *		one or more subtitles have been created. 
 	 * "framerate-changed"
 	 *		the framerate value of document changed.
 	 * "timing-mode-changed"
@@ -289,11 +293,17 @@ public:
 	 *		the (external) timing mode of the document editing changed.
 	 * "document-changed"
 	 *		the document has changed after the editing of something like subtitle, metadata ...	
+	 * "style-changed"
+	 * 		one or more styles have been changed.
+	 * "style-deleted"
+	 *		one or more styles have been removed.
+	 * "style-insered"
+	 *		one or more styles have been created. 
 	 */
 	sigc::signal<void>& get_signal(const std::string &name);
 
 	/*
- 	 * Emit a signal from his name.
+ 	 * Emit a signal from its name.
 	 */
 	void emit_signal(const std::string &name);
 
