@@ -23,8 +23,7 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <glibmm/ustring.h>
-#include <glibmm/module.h>
+#include <glibmm.h>
 #include "extension.h"
 
 /*
