@@ -21,7 +21,6 @@
  */
 
 #include <config.h>
-#include <gtkmm/scrolledwindow.h>
 #include <gtkmm/accelmap.h>
 #include "utility.h"
 #include "application.h"
@@ -42,6 +41,7 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builde
 	builder->get_widget_derived("statusbar", m_statusbar);
 
 	builder->get_widget("vbox-main", m_vboxMain);
+	builder->get_widget("paned-main", m_paned_main);
 	builder->get_widget("paned-multimedia", m_paned_multimedia);
 	builder->get_widget_derived("video-player", m_video_player);
 	builder->get_widget_derived("waveform-editor", m_waveform_editor);
@@ -80,6 +80,7 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builde
 	Config::getInstance().signal_changed("interface").connect(
 			sigc::mem_fun(*this, &Application::on_config_interface_changed));
 
+	load_window_state();
 	show();
 
 	m_menubar.create(*this, *m_statusbar);
@@ -90,7 +91,7 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builde
 
 	// open subtitle files with drag-and-drop in NoteBook
 	{
-		std::list<Gtk::TargetEntry> targets;
+		std::vector<Gtk::TargetEntry> targets;
 
 		targets.push_back(Gtk::TargetEntry("text/uri-list", Gtk::TargetFlags(0), 0));
 		
@@ -100,7 +101,7 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builde
 	}
 	// open video files with drag-and-drop in Player
 	{
-		std::list<Gtk::TargetEntry> targets;
+		std::vector<Gtk::TargetEntry> targets;
 
 		targets.push_back(Gtk::TargetEntry("text/uri-list", Gtk::TargetFlags(0), 0));
 		
@@ -108,6 +109,16 @@ Application::Application(BaseObjectType *cobject, const Glib::RefPtr<Gtk::Builde
 				sigc::mem_fun(*this, &Application::player_drag_data_received));
 		m_video_player->drag_dest_set(targets, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
 	}
+	// open waveform or keyframes files with drag-and-drop in waveform view
+	{
+		std::vector<Gtk::TargetEntry> targets;
+
+		targets.push_back(Gtk::TargetEntry("text/uri-list", Gtk::TargetFlags(0), 0));
+		
+		m_waveform_editor->signal_drag_data_received().connect(
+				sigc::mem_fun(*this, &Application::waveform_drag_data_received));
+		m_waveform_editor->drag_dest_set(targets, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
+	}
 }
 
 /*
@@ -163,6 +174,8 @@ bool Application::on_delete_event(GdkEventAny *ev)
 	Glib::ustring path_se_accelmap = get_config_dir("accelmap");
 	Gtk::AccelMap::save(path_se_accelmap);
 
+	save_window_sate();
+
 	return res;
 }
 
@@ -210,10 +223,6 @@ void Application::on_document_create(Document *doc)
 			sigc::bind<Document*>(
 				sigc::mem_fun(*this, &Application::on_close_document), doc));
 
-	// rcstyle for the button
-	close_button->get_modifier_style()->set_xthickness(0);
-	close_button->get_modifier_style()->set_ythickness(0);
-	
 	// close image 
 	image = manage(new Gtk::Image(Gtk::Stock::CLOSE, Gtk::ICON_SIZE_MENU));
 	close_button->add(*image);
@@ -407,7 +416,7 @@ void Application::on_close_document(Document *doc)
  *	Changement dans le notebook de la page editer
  *	On recupere la page pusi on init DocumentManager avec le document
  */
-void Application::on_signal_switch_page(GtkNotebookPage* page, guint page_num)
+void Application::on_signal_switch_page(Gtk::Widget* /*page*/, guint page_num)
 {
 	se_debug(SE_DEBUG_APP);
 
@@ -665,7 +674,7 @@ bool Application::on_key_press_event(GdkEventKey *ev)
 /*
  *
  */
-void Application::notebook_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time)
+void Application::notebook_drag_data_received(const Glib::RefPtr<Gdk::DragContext>& /*context*/, int /*x*/, int /*y*/, const Gtk::SelectionData& selection_data, guint /*info*/, guint /*time*/)
 {
 	std::vector<Glib::ustring> uris = selection_data.get_uris();
 	for(unsigned int i=0; i<uris.size(); ++i)
@@ -684,7 +693,7 @@ void Application::notebook_drag_data_received(const Glib::RefPtr<Gdk::DragContex
 
 /*
  */
-void Application::player_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, const Gtk::SelectionData& selection_data, guint info, guint time)
+void Application::player_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& /*context*/, int /*x*/, int /*y*/, const Gtk::SelectionData& selection_data, guint /*info*/, guint /*time*/)
 {
 	std::vector<Glib::ustring> uris = selection_data.get_uris();
 	if(uris.size() >= 1)
@@ -693,6 +702,23 @@ void Application::player_drag_data_received (const Glib::RefPtr<Gdk::DragContext
 	}
 }
 
+/*
+ */
+void Application::waveform_drag_data_received (const Glib::RefPtr<Gdk::DragContext>& /*context*/, int /*x*/, int /*y*/, const Gtk::SelectionData& selection_data, guint /*info*/, guint /*time*/)
+{
+	std::vector<Glib::ustring> uris = selection_data.get_uris();
+	for(guint i=0; i< uris.size(); ++i)
+	{
+		Glib::ustring uri = uris[i];
+		Glib::RefPtr<KeyFrames> kf = KeyFrames::create_from_file(uri);
+		if(kf)
+			m_video_player->player()->set_keyframes(kf);
+		else if(Glib::RefPtr<Waveform> wf = Waveform::create_from_file(uri))
+			m_waveform_editor->set_waveform(wf);
+	}
+}
+
+
 
 /*
  *
@@ -780,9 +806,9 @@ void Application::on_paned_multimedia_visibility_child_changed()
 	bool state2 = false;
 
 	if(child1 != NULL)
-		state1 = child1->is_visible();
+		state1 = child1->get_visible();
 	if(child2 != NULL)
-		state2 = child2->is_visible();
+		state2 = child2->get_visible();
 
 	if(state1 || state2)
 		m_paned_multimedia->show();
@@ -790,3 +816,62 @@ void Application::on_paned_multimedia_visibility_child_changed()
 		m_paned_multimedia->hide();
 }
 
+/*
+ */
+void Application::load_window_state()
+{
+	Config &cfg = Config::getInstance();
+
+	// window size,position
+	if(cfg.get_value_bool("interface", "window-maximized"))
+		maximize();
+	else
+	{
+		int window_x, window_y;
+		if(cfg.get_value_int("interface", "window-x", window_x) && cfg.get_value_int("interface", "window-y", window_y))
+			move(window_x, window_y);
+
+		int window_width, window_height;
+		if(cfg.get_value_int("interface", "window-width", window_width) && cfg.get_value_int("interface", "window-height", window_height))
+			resize(window_width, window_height);
+	}
+	// paned position
+	int panel_main_position = cfg.get_value_int("interface", "paned-main-position");
+	if(panel_main_position > 0)
+		m_paned_main->set_position(panel_main_position);
+
+	int panel_multimedia_position = cfg.get_value_int("interface", "paned-multimedia-position");
+	if(panel_multimedia_position > 0)
+		m_paned_multimedia->set_position(panel_multimedia_position);
+}
+
+/*
+ */
+void Application::save_window_sate()
+{
+	Config &cfg = Config::getInstance();
+
+	// position of window
+	int window_x = 0, window_y = 0;
+	get_position(window_x, window_y);
+	cfg.set_value_int("interface", "window-x", window_x);
+	cfg.set_value_int("interface", "window-y", window_y);
+
+	// size of window
+#if GTKMM_CHECK_VERSION(3,12,0)
+	if(is_maximized())
+#else
+	if(get_window()->get_state() & (Gdk::WINDOW_STATE_MAXIMIZED | Gdk::WINDOW_STATE_FULLSCREEN) == 0)
+#endif
+		cfg.set_value_bool("interface", "maximize-window", true);
+	else
+	{
+		Gtk::Allocation allocation = get_allocation();
+		cfg.set_value_int("interface", "window-width", allocation.get_width());
+		cfg.set_value_int("interface", "window-height", allocation.get_height());
+	}
+
+	// paned position
+	cfg.set_value_int("interface", "paned-main-position", m_paned_main->get_position());
+	cfg.set_value_int("interface", "paned-multimedia-position", m_paned_multimedia->get_position());
+}
