@@ -23,8 +23,7 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtkmm/cellrenderertext.h>
-#include <gtkmm/entry.h>
+#include <gtkmm.h>
 #include <debug.h>
 #include "cellrenderercustom.h"
 
@@ -91,12 +90,12 @@ CellRendererCustom<T>::CellRendererCustom()
  */
 template<class T>
 Gtk::CellEditable* CellRendererCustom<T>::start_editing_vfunc(
-			GdkEvent* event, 
-			Gtk::Widget &widget, 
+			GdkEvent* /*event*/, 
+			Gtk::Widget &/*widget*/, 
 			const Glib::ustring &path, 
-			const Gdk::Rectangle& background_area,
+			const Gdk::Rectangle& /*background_area*/,
 			const Gdk::Rectangle& cell_area,
-			Gtk::CellRendererState flags)
+			Gtk::CellRendererState /*flags*/)
 {
 	se_debug(SE_DEBUG_VIEW);
 
@@ -135,6 +134,7 @@ Gtk::CellEditable* CellRendererCustom<T>::start_editing_vfunc(
 template<class T>
 void CellRendererCustom<T>::begin_editing()
 {
+	se_debug(SE_DEBUG_VIEW);
 }
 
 /*
@@ -143,6 +143,7 @@ void CellRendererCustom<T>::begin_editing()
 template<class T>
 void CellRendererCustom<T>::finish_editing()
 {
+	se_debug(SE_DEBUG_VIEW);
 }
 
 /*
@@ -165,6 +166,8 @@ void CellRendererCustom<T>::cell_editing_done(const Glib::ustring &path)
 	// Define to NULL to avoid a duplicate call
 	m_editable = NULL;
 	edited(path, text);
+
+	finish_editing();
 }
 
 #endif//_cellrenderercustom_h
