@@ -22,8 +22,8 @@
  *	You should have received a copy of the GNU General Public License
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/builder.h>
+#include <gtkmm.h>
+#include <gtkmm.h>
 
 /*
  * ComboBox for choosing the format of subtitle.
