@@ -23,8 +23,7 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/builder.h>
+#include <gtkmm.h>
 
 /*
  * The combobox display all videos on the current folder.
