@@ -40,12 +40,13 @@ void init_dialog_subtitle_filters(Gtk::FileChooserDialog *dialog)
 	std::list<SubtitleFormatInfo>::const_iterator it;
 	std::list<SubtitleFormatInfo> infos = SubtitleFormatSystem::instance().get_infos();
 
-	Gtk::FileFilter *all=manage(new Gtk::FileFilter), *supported = manage(new Gtk::FileFilter);
+	Glib::RefPtr<Gtk::FileFilter> all= Gtk::FileFilter::create();
+	Glib::RefPtr<Gtk::FileFilter> supported= Gtk::FileFilter::create();
 	// all files
 	{
 		all->set_name(_("All files (*.*)"));
 		all->add_pattern("*");
-		dialog->add_filter(*all);
+		dialog->add_filter(all);
 	}
 
 	// all supported formats
@@ -57,7 +58,7 @@ void init_dialog_subtitle_filters(Gtk::FileChooserDialog *dialog)
 			supported->add_pattern("*." + (*it).extension.uppercase());
 		}
 
-		dialog->add_filter(*supported);
+		dialog->add_filter(supported);
 	}
 
 	// by format
@@ -67,16 +68,16 @@ void init_dialog_subtitle_filters(Gtk::FileChooserDialog *dialog)
 			Glib::ustring name = (*it).name;
 			Glib::ustring ext = (*it).extension;
 
-			Gtk::FileFilter *filter = manage(new Gtk::FileFilter);
+			Glib::RefPtr<Gtk::FileFilter> filter= Gtk::FileFilter::create();
 			filter->set_name(name + " (" + ext + ")");
 			filter->add_pattern("*." + ext);
 			filter->add_pattern("*." + ext.uppercase());
-			dialog->add_filter(*filter);
+			dialog->add_filter(filter);
 		}
 	}
 
 	// select by default
-	dialog->set_filter(*supported);
+	dialog->set_filter(supported);
 }
 
 /*
@@ -96,6 +97,18 @@ DialogFileChooser::DialogFileChooser(BaseObjectType* cobject, const Glib::ustrin
 	utility::set_transient_parent(*this);
 }
 
+/*
+ */
+DialogFileChooser::DialogFileChooser(const Glib::ustring &title, Gtk::FileChooserAction action, const Glib::ustring &name)
+:Gtk::FileChooserDialog(title, action), m_name(name)
+{
+	Glib::ustring last;
+	if(Config::getInstance().get_value_string("dialog-last-folder", m_name, last))
+		set_current_folder_uri(last);
+
+	utility::set_transient_parent(*this);
+}
+
 /*
  *
  */
@@ -111,17 +124,48 @@ DialogFileChooser::~DialogFileChooser()
  */
 void DialogFileChooser::set_current_filter(const Glib::ustring &subtitleformat_name)
 {
-	std::list<Gtk::FileFilter*> filters = list_filters();
-	for(std::list<Gtk::FileFilter*>::const_iterator it = filters.begin(); it != filters.end(); ++it)
+	std::vector< Glib::RefPtr<Gtk::FileFilter> > filters = list_filters();
+	for(std::vector< Glib::RefPtr<Gtk::FileFilter> >::const_iterator it = filters.begin(); it != filters.end(); ++it)
 	{
 		if((*it)->get_name().find(subtitleformat_name) == Glib::ustring::npos)
 			continue;
 		
-		set_filter(*(*it));
+		set_filter(*it);
 		return;
 	}
 }
 
+/*
+ * This can be use to setup the document name based on video uri
+ */
+void DialogFileChooser::set_filename_from_another_uri(const Glib::ustring &another_uri, const Glib::ustring &ext)
+{
+	try
+	{
+		Glib::ustring filename = Glib::filename_from_uri(another_uri);
+		Glib::ustring pathname = Glib::path_get_dirname(filename);
+		Glib::ustring basename = Glib::path_get_basename(filename);
+
+		basename = utility::add_or_replace_extension(basename, ext);
+
+		set_current_folder(pathname); // set_current_folder_uri ?
+		set_current_name(basename);
+	}
+	catch(const Glib::Exception &ex)
+	{
+		std::cerr << "set_filename_from_another_uri failed : " << ex.what() << std::endl;
+	}
+}
+
+/*
+ * Internally call set_current_folder and set_current_name with dirname and basename
+ */
+void DialogFileChooser::set_current_folder_and_name(const Glib::ustring &filename)
+{
+	set_current_folder( Glib::path_get_dirname(filename) );
+	set_current_name( Glib::path_get_basename(filename) );
+}
+
 
 /*
  * DialogOpenDocument
@@ -217,7 +261,7 @@ void DialogOpenDocument::on_current_folder_changed()
  */
 void DialogOpenDocument::on_selection_changed()
 {
-	std::list<Glib::ustring> selected = get_filenames();
+	std::vector<std::string> selected = get_filenames();
 
 	if(selected.size() == 1)
 		m_comboVideo->auto_select_video(selected.front());
@@ -309,26 +353,17 @@ Glib::ustring DialogSaveDocument::get_newline() const
  */
 void DialogSaveDocument::on_combo_format_changed()
 {
-	Glib::ustring filename = get_filename();
-	if(filename.empty())
-		return;
+	Glib::ustring basename = get_current_name();
 
-	// Only work with the name of the file
-	Glib::ustring basename = Glib::path_get_basename(filename);
+	if(basename.empty())
+		return;
 
 	// Try to get the extension from the format
 	SubtitleFormatInfo sfinfo;
 	if(SubtitleFormatSystem::instance().get_info(get_format(), sfinfo) == false)
 		return;
-	
-	// Test if the name already have an extension then replace the 
-	// previous extension by the new one or simply add the extension to the name.
-	Glib::RefPtr<Glib::Regex> re = Glib::Regex::create("^(.*)(\\.)(.*)$");
-	if(re->match(basename))
-		basename = re->replace(basename, 0, "\\1." + sfinfo.extension, Glib::RegexMatchFlags(0));
-	else
-		basename = basename + "." + sfinfo.extension;
-
+	// Change the extension according to the format selected
+	basename = utility::add_or_replace_extension(basename, sfinfo.extension);
 	// Update only the current name
 	set_current_name(basename);
 }
@@ -475,28 +510,28 @@ DialogOpenVideo::DialogOpenVideo()
 	utility::set_transient_parent(*this);
 
 	// video filter
-	Gtk::FileFilter m_filterVideo;
-	m_filterVideo.set_name(_("Video"));
-	m_filterVideo.add_pattern("*.avi");
-	m_filterVideo.add_pattern("*.wma");
-	m_filterVideo.add_pattern("*.mkv");
-	m_filterVideo.add_pattern("*.mpg");
-	m_filterVideo.add_pattern("*.mpeg");
-	m_filterVideo.add_mime_type("video/*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterVideo= Gtk::FileFilter::create();
+	m_filterVideo->set_name(_("Video"));
+	m_filterVideo->add_pattern("*.avi");
+	m_filterVideo->add_pattern("*.wma");
+	m_filterVideo->add_pattern("*.mkv");
+	m_filterVideo->add_pattern("*.mpg");
+	m_filterVideo->add_pattern("*.mpeg");
+	m_filterVideo->add_mime_type("video/*");
 	add_filter(m_filterVideo);
 
 	// audio filter
-	Gtk::FileFilter m_filterAudio;
-	m_filterAudio.set_name(_("Audio"));
-	m_filterAudio.add_pattern("*.mp3");
-	m_filterAudio.add_pattern("*.ogg");
-	m_filterAudio.add_pattern("*.wav");
-	m_filterAudio.add_mime_type("audio/*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterAudio= Gtk::FileFilter::create();
+	m_filterAudio->set_name(_("Audio"));
+	m_filterAudio->add_pattern("*.mp3");
+	m_filterAudio->add_pattern("*.ogg");
+	m_filterAudio->add_pattern("*.wav");
+	m_filterAudio->add_mime_type("audio/*");
 	add_filter(m_filterAudio);
 
-	Gtk::FileFilter m_filterAll;
-	m_filterAll.set_name(_("ALL"));
-	m_filterAll.add_pattern("*.*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterAll= Gtk::FileFilter::create();
+	m_filterAll->set_name(_("ALL"));
+	m_filterAll->add_pattern("*.*");
 	add_filter(m_filterAll);
 	
 	
@@ -531,51 +566,51 @@ DialogOpenWaveform::DialogOpenWaveform()
 	utility::set_transient_parent(*this);
 
 	// waveform, video and audio filter
-	Gtk::FileFilter m_filterSupported;
-	m_filterSupported.set_name(_("Waveform & Media"));
-	m_filterSupported.add_pattern("*.wf");
-	m_filterSupported.add_mime_type("video/*");
-	m_filterSupported.add_pattern("*.avi");
-	m_filterSupported.add_pattern("*.wma");
-	m_filterSupported.add_pattern("*.mkv");
-	m_filterSupported.add_pattern("*.mpg");
-	m_filterSupported.add_pattern("*.mpeg");
-	m_filterSupported.add_mime_type("audio/*");
-	m_filterSupported.add_pattern("*.mp3");
-	m_filterSupported.add_pattern("*.ogg");
-	m_filterSupported.add_pattern("*.wav");
+	Glib::RefPtr<Gtk::FileFilter> m_filterSupported= Gtk::FileFilter::create();
+	m_filterSupported->set_name(_("Waveform & Media"));
+	m_filterSupported->add_pattern("*.wf");
+	m_filterSupported->add_mime_type("video/*");
+	m_filterSupported->add_pattern("*.avi");
+	m_filterSupported->add_pattern("*.wma");
+	m_filterSupported->add_pattern("*.mkv");
+	m_filterSupported->add_pattern("*.mpg");
+	m_filterSupported->add_pattern("*.mpeg");
+	m_filterSupported->add_mime_type("audio/*");
+	m_filterSupported->add_pattern("*.mp3");
+	m_filterSupported->add_pattern("*.ogg");
+	m_filterSupported->add_pattern("*.wav");
 	add_filter(m_filterSupported);
 
 	// waveform filter
-	Gtk::FileFilter m_filterWaveform;
-	m_filterWaveform.set_name(_("Waveform (*.wf)"));
-	m_filterWaveform.add_pattern("*.wf");
+	Glib::RefPtr<Gtk::FileFilter> m_filterWaveform= Gtk::FileFilter::create();
+	m_filterWaveform->set_name(_("Waveform (*.wf)"));
+	m_filterWaveform->add_pattern("*.wf");
 	add_filter(m_filterWaveform);
 
 	// movies filter
-	Gtk::FileFilter m_filterMovie;
-	m_filterMovie.set_name(_("Video"));
-	m_filterMovie.add_pattern("*.avi");
-	m_filterMovie.add_pattern("*.wma");
-	m_filterMovie.add_pattern("*.mkv");
-	m_filterMovie.add_pattern("*.mpg");
-	m_filterMovie.add_pattern("*.mpeg");
-	m_filterMovie.add_mime_type("video/*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterMovie= Gtk::FileFilter::create();
+	m_filterMovie->set_name(_("Video"));
+	m_filterMovie->add_pattern("*.avi");
+	m_filterMovie->add_pattern("*.wma");
+	m_filterMovie->add_pattern("*.mkv");
+	m_filterMovie->add_pattern("*.mpg");
+	m_filterMovie->add_pattern("*.mpeg");
+	m_filterMovie->add_mime_type("video/*");
 	add_filter(m_filterMovie);
 
 	// audio filter
-	Gtk::FileFilter m_filterAudio;
-	m_filterAudio.set_name(_("Audio"));
-	m_filterAudio.add_pattern("*.mp3");
-	m_filterAudio.add_pattern("*.ogg");
-	m_filterAudio.add_pattern("*.wav");
-	m_filterAudio.add_mime_type("audio/*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterAudio= Gtk::FileFilter::create();
+	m_filterAudio->set_name(_("Audio"));
+	m_filterAudio->add_pattern("*.mp3");
+	m_filterAudio->add_pattern("*.ogg");
+	m_filterAudio->add_pattern("*.wav");
+	m_filterAudio->add_mime_type("audio/*");
 	add_filter(m_filterAudio);
 
 	// all filter
-	Gtk::FileFilter m_filterAll;
-	m_filterAll.set_name(_("ALL"));
-	m_filterAll.add_pattern("*.*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterAll= Gtk::FileFilter::create();
+	m_filterAll->set_name(_("ALL"));
+	m_filterAll->add_pattern("*.*");
 	add_filter(m_filterAll);
 	
 	
@@ -611,38 +646,38 @@ DialogOpenKeyframe::DialogOpenKeyframe()
 	utility::set_transient_parent(*this);
 
 	// keyframes and video filter
-	Gtk::FileFilter m_filterSupported;
-	m_filterSupported.set_name(_("Keyframe & Media"));
-	m_filterSupported.add_pattern("*.kf");
-	m_filterSupported.add_mime_type("video/*");
-	m_filterSupported.add_pattern("*.avi");
-	m_filterSupported.add_pattern("*.wma");
-	m_filterSupported.add_pattern("*.mkv");
-	m_filterSupported.add_pattern("*.mpg");
-	m_filterSupported.add_pattern("*.mpeg");
+	Glib::RefPtr<Gtk::FileFilter> m_filterSupported= Gtk::FileFilter::create();
+	m_filterSupported->set_name(_("Keyframe & Media"));
+	m_filterSupported->add_pattern("*.kf");
+	m_filterSupported->add_mime_type("video/*");
+	m_filterSupported->add_pattern("*.avi");
+	m_filterSupported->add_pattern("*.wma");
+	m_filterSupported->add_pattern("*.mkv");
+	m_filterSupported->add_pattern("*.mpg");
+	m_filterSupported->add_pattern("*.mpeg");
 	add_filter(m_filterSupported);
 
 	// keyframe filter
-	Gtk::FileFilter m_filterKeyframe;
-	m_filterKeyframe.set_name(_("Keyframe (*.kf)"));
-	m_filterKeyframe.add_pattern("*.kf");
+	Glib::RefPtr<Gtk::FileFilter> m_filterKeyframe= Gtk::FileFilter::create();
+	m_filterKeyframe->set_name(_("Keyframe (*.kf)"));
+	m_filterKeyframe->add_pattern("*.kf");
 	add_filter(m_filterKeyframe);
 
 	// movies filter
-	Gtk::FileFilter m_filterMovie;
-	m_filterMovie.set_name(_("Video"));
-	m_filterMovie.add_pattern("*.avi");
-	m_filterMovie.add_pattern("*.wma");
-	m_filterMovie.add_pattern("*.mkv");
-	m_filterMovie.add_pattern("*.mpg");
-	m_filterMovie.add_pattern("*.mpeg");
-	m_filterMovie.add_mime_type("video/*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterMovie= Gtk::FileFilter::create();
+	m_filterMovie->set_name(_("Video"));
+	m_filterMovie->add_pattern("*.avi");
+	m_filterMovie->add_pattern("*.wma");
+	m_filterMovie->add_pattern("*.mkv");
+	m_filterMovie->add_pattern("*.mpg");
+	m_filterMovie->add_pattern("*.mpeg");
+	m_filterMovie->add_mime_type("video/*");
 	add_filter(m_filterMovie);
 
 	// all filter
-	Gtk::FileFilter m_filterAll;
-	m_filterAll.set_name(_("ALL"));
-	m_filterAll.add_pattern("*.*");
+	Glib::RefPtr<Gtk::FileFilter> m_filterAll= Gtk::FileFilter::create();
+	m_filterAll->set_name(_("ALL"));
+	m_filterAll->add_pattern("*.*");
 	add_filter(m_filterAll);
 	
 	
