@@ -66,14 +66,27 @@ void MenuBar::create(Gtk::Window &window, Statusbar &statusbar)
 	actiongroup->add(Gtk::Action::create("menu-timings", _("_Timings")));
 	actiongroup->add(Gtk::Action::create("menu-tools", _("T_ools")));
 	actiongroup->add(Gtk::Action::create("menu-video", _("_Video")));
+	actiongroup->add(Gtk::Action::create("menu-keyframes", _("_Keyframes")));
 	actiongroup->add(Gtk::Action::create("menu-waveform", _("_Waveform")));
 	actiongroup->add(Gtk::Action::create("menu-view", _("V_iew")));
 	actiongroup->add(Gtk::Action::create("menu-options", _("_Options")));
-	actiongroup->add(Gtk::Action::create("menu-extensions", _("_Extensions")));
+	actiongroup->add(Gtk::Action::create("menu-extensions", _("E_xtensions")));
 	actiongroup->add(Gtk::Action::create("menu-help", _("_Help")));
+	// file submenu
+	actiongroup->add(Gtk::Action::create("menu-open", _("_Open")));
+	actiongroup->add(Gtk::Action::create("menu-save", _("_Save")));
+	actiongroup->add(Gtk::Action::create("menu-import", _("_Import")));
+	actiongroup->add(Gtk::Action::create("menu-export", _("_Export")));
+	// If we add the stock_id when we create the actions, 
+	// they will automatically set up with the 
+	// default shortcut (Open: Ctrl+O, Save: Ctrl+S). 
+	// This make a conflict with others actions.  
+#if GTKMM_CHECK_VERSION(2,16,0)
+	actiongroup->get_action("menu-open")->set_stock_id(Gtk::Stock::OPEN);
+	actiongroup->get_action("menu-save")->set_stock_id(Gtk::Stock::SAVE);
+#endif//GTKMM_CHECK_VERSION(2, 16, 0)
 
 	// UIManager
-
 	m_refUIManager->signal_connect_proxy().connect(
 			sigc::mem_fun(*this, &MenuBar::connect_proxy));
 
