@@ -36,7 +36,7 @@ SpinButtonTime::SpinButtonTime()
 /*
  *
  */
-SpinButtonTime::SpinButtonTime(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
+SpinButtonTime::SpinButtonTime(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /*builder*/)
 :Gtk::SpinButton(cobject)
 {
 	default_init();
@@ -114,11 +114,9 @@ int SpinButtonTime::on_input(double *new_value)
 		Glib::ustring text = get_text();
 
 		if(SubtitleTime::validate(text))
-		{
 			*new_value = (double) SubtitleTime(text).totalmsecs;
-		}
 		else
-			g_warning("Invalid value");
+			*new_value = get_value();
 
 		return true;
 	}
@@ -149,25 +147,20 @@ bool SpinButtonTime::on_output()
 		
 	std::string text = build_message("%s%01d:%02d:%02d.%03d", sign.c_str(), time.hours(), time.minutes(), time.seconds(), time.mseconds());
 
-	set_numeric(false);
 	set_text(text);
-	set_numeric(true);
 
 	return true;
 }
 
 /*
- *
  */
-void SpinButtonTime::on_size_request(Gtk::Requisition *req)
+void SpinButtonTime::get_preferred_width_vfunc(int &minimum_width, int &natural_width) const
 {
-	Gtk::Widget::on_size_request(req);
+	Gtk::SpinButton::get_preferred_width_vfunc(minimum_width, natural_width);
 	if(m_timing_mode == TIME)
 	{
-		int width, height;
-		create_pango_layout("-0:00:00.000")->get_pixel_size(width, height);
-
-		req->width = width + 30;//25;
+		minimum_width += 30;
+		natural_width += 30;
 	}
 }
 
