@@ -30,10 +30,10 @@
  * Initialize the widget with the AutomaticSpellChecker.
  */
 TextViewCell::TextViewCell()
-:	Glib::ObjectBase(typeid(TextViewCell)),
-	Gtk::CellEditable(), 
+:	Gtk::CellEditable(),
 	m_editing_canceled(false), 
-	m_used_ctrl_enter_to_confirm_change(false)
+	m_used_ctrl_enter_to_confirm_change(false),
+    Glib::ObjectBase(typeid(TextViewCell))
 {
 	se_debug(SE_DEBUG_VIEW);
 
@@ -87,7 +87,7 @@ bool TextViewCell::on_key_press_event(GdkEventKey* event)
 {
 	se_debug(SE_DEBUG_VIEW);
 
-	if(event->keyval == GDK_Escape)
+	if(event->keyval == GDK_KEY_Escape)
 	{
 		m_editing_canceled = true;
 		remove_widget();
@@ -95,10 +95,10 @@ bool TextViewCell::on_key_press_event(GdkEventKey* event)
 	}
 
 	bool st_enter = (
-			 event->keyval == GDK_Return ||  
-			 event->keyval == GDK_KP_Enter ||  
-			 event->keyval == GDK_ISO_Enter ||  
-			 event->keyval == GDK_3270_Enter );
+			 event->keyval == GDK_KEY_Return ||  
+			 event->keyval == GDK_KEY_KP_Enter ||  
+			 event->keyval == GDK_KEY_ISO_Enter ||  
+			 event->keyval == GDK_KEY_3270_Enter );
 
 	bool st_ctrl = (event->state & GDK_CONTROL_MASK);
 
@@ -124,3 +124,15 @@ void TextViewCell::on_remove_widget()
 		editing_done();
 	Gtk::CellEditable::on_remove_widget();
 }
+
+/*
+ * bug #23569 : Cursor cannot be moved with mouse when editing subtitles
+ */
+bool TextViewCell::on_button_press_event (GdkEventButton*event)
+{
+	se_debug(SE_DEBUG_VIEW);
+
+	Gtk::TextView::on_button_press_event(event);
+	return true;
+}
+
