@@ -23,13 +23,12 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtkmm/textview.h>
-#include <gtkmm/celleditable.h>
+#include <gtkmm.h>
 
 /*
  * Cell text editable with multiline support.
  */
-class TextViewCell : public Gtk::TextView, public Gtk::CellEditable
+class TextViewCell : public Gtk::CellEditable, public Gtk::TextView
 {
 public:
 
@@ -62,6 +61,11 @@ protected:
 	 */
 	bool on_key_press_event(GdkEventKey* event);
 
+	/*
+	 * bug #23569 : Cursor cannot be moved with mouse when editing subtitles
+	 */
+	bool on_button_press_event (GdkEventButton*event);
+
 	/*
 	 * Before removing the widget we call editing_done 
 	 * if there's no canceled signal.
