@@ -24,8 +24,7 @@
  */
  
 
-#include <gtkmm/treeview.h>
-#include <gtkmm/builder.h>
+#include <gtkmm.h>
 #include "stylemodel.h"
 #include "cfg.h"
 
