@@ -47,7 +47,7 @@ public:
 		m_hscale_seek->set_range(0, 1);
 		m_hscale_seek->set_value(0);
 		m_hscale_seek->set_increments(0.05, 0.05);//get_adjustment()->set_step_increment(0.05);
-		m_hscale_seek->set_update_policy(Gtk::UPDATE_CONTINUOUS);
+		//m_hscale_seek->set_update_policy(Gtk::UPDATE_CONTINUOUS);
 		m_hscale_seek->set_value_pos(Gtk::POS_RIGHT);
 		
 		m_hscale_seek->signal_format_value().connect(
@@ -155,7 +155,7 @@ public:
 
 	/*
 	 */
-	void on_player_tick(long current_time, long stream_length, double current_position)
+	void on_player_tick(long /*current_time*/, long /*stream_length*/, double current_position)
 	{
 		m_connection_scale_changed.block();
 		set_seek_position(current_position);
@@ -219,7 +219,7 @@ protected:
 	// controls
 	Gtk::Button* m_button_play;
 	Gtk::Button* m_button_pause;
-	Gtk::HScale* m_hscale_seek;
+	Gtk::Scale* m_hscale_seek;
 	bool m_current_seek;
 	sigc::connection m_connection_scale_changed;
 	Player* m_player;
@@ -352,7 +352,7 @@ void VideoPlayer::on_current_document_changed(Document *doc)
 /*
  * Check or search the good subtitle (find_subtitle).
  */
-void VideoPlayer::on_player_tick(long current_time, long stream_length, double current_position)
+void VideoPlayer::on_player_tick(long /*current_time*/, long /*stream_length*/, double /*current_position*/)
 {
 	find_subtitle();
 }
