@@ -38,7 +38,7 @@ WaveformRenderer* create_waveform_renderer_gl();
  *
  */
 WaveformEditor::WaveformEditor(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
-:Gtk::HBox(cobject), m_waveformRenderer(NULL), m_document(NULL), m_player(NULL)
+:Gtk::Box(cobject), m_waveformRenderer(NULL), m_document(NULL), m_player(NULL)
 {
 	set_size_request(240, 240);
 
@@ -80,7 +80,7 @@ WaveformEditor::WaveformEditor(BaseObjectType* cobject, const Glib::RefPtr<Gtk::
 	Config::getInstance().signal_changed("waveform").connect(
 			sigc::mem_fun(*this, &WaveformEditor::on_config_waveform_changed));
 	
-	set_sensitive(false);
+	set_child_sensitive(false);
 }
 
 /*
@@ -292,7 +292,7 @@ Player* WaveformEditor::player()
  */
 void WaveformEditor::on_map()
 {
-	Gtk::HBox::on_map();
+	Gtk::Box::on_map();
 
 	if(m_connection_player_tick)
 	{
@@ -308,7 +308,7 @@ void WaveformEditor::on_map()
  */
 void WaveformEditor::on_unmap()
 {
-	Gtk::HBox::on_unmap();
+	Gtk::Box::on_unmap();
 
 	if(m_connection_player_tick)
 	{
@@ -320,7 +320,7 @@ void WaveformEditor::on_unmap()
 /*
  *
  */
-void WaveformEditor::on_player_tick(long current_time, long stream_length, double current_position)
+void WaveformEditor::on_player_tick(long /*current_time*/, long /*stream_length*/, double /*current_position*/)
 {
 	if(has_renderer() && player() && has_waveform())
 	{
@@ -386,7 +386,7 @@ int WaveformEditor::get_zoom()
  * This callback is connected to the signal "configure" of the waveform.
  * Every time this size changed, the scrollbar need to be recalculate.
  */
-bool WaveformEditor::on_configure_event_waveform(GdkEventConfigure *ev)
+bool WaveformEditor::on_configure_event_waveform(GdkEventConfigure * /*ev*/)
 {
 	se_debug(SE_DEBUG_WAVEFORM);
 
@@ -424,7 +424,7 @@ void WaveformEditor::init_scrollbar()
 	double upper = m_hscrollbarWaveformRenderer->get_adjustment()->get_upper();
 	double old_value = m_hscrollbarWaveformRenderer->get_value();
 
-	Gtk::Adjustment *adj = m_hscrollbarWaveformRenderer->get_adjustment();
+	Glib::RefPtr<Gtk::Adjustment> adj = m_hscrollbarWaveformRenderer->get_adjustment();
 
 	adj->set_page_size((double)width);
 	adj->set_page_increment(width);
@@ -524,14 +524,19 @@ void WaveformEditor::set_waveform(const Glib::RefPtr<Waveform> &wf)
 
 	m_waveform = wf;
 
-	Config::getInstance().set_value_bool("waveform", "display", (bool)wf);
+	// Only show the wf view if it's not already visible
+	// Don't show or hide using the wf status
+	// bug #22482 : Another regression of gtk3 port
+	Config &cfg = Config::getInstance();
+	if(cfg.get_value_bool("waveform", "display") == false && wf)
+		cfg.set_value_bool("waveform", "display", true);
 
 	if(has_renderer())
 		renderer()->set_waveform(wf);
 	else
 		std::cerr << "You need a WaveformRenderer!!" << std::endl;
 
-	set_sensitive((bool)wf && has_renderer());
+	set_child_sensitive((bool)wf && has_renderer());
 
 	m_signal_waveform_changed.emit();
 
@@ -782,7 +787,7 @@ bool WaveformEditor::on_button_press_event_renderer(GdkEventButton *ev)
 {
 	se_debug(SE_DEBUG_WAVEFORM);
 
-	if(!has_renderer())
+	if(!has_renderer() || !has_waveform())
 		return true;
 
 	// the time of the mouse in the area
@@ -842,7 +847,7 @@ bool WaveformEditor::on_button_press_event_renderer(GdkEventButton *ev)
  * Finish the editing of the current subtitle. 
  * Stop the recorder command.
  */
-bool WaveformEditor::on_button_release_event_renderer(GdkEventButton *ev)
+bool WaveformEditor::on_button_release_event_renderer(GdkEventButton * /*ev*/)
 {
 	se_debug(SE_DEBUG_WAVEFORM);
 
@@ -931,6 +936,15 @@ bool WaveformEditor::on_scroll_event_renderer(GdkEventScroll *ev)
 	return true;
 }
 
+/*
+ */
+void WaveformEditor::set_child_sensitive(bool status)
+{
+	m_hscrollbarWaveformRenderer->set_sensitive(status);
+	m_sliderZoom->set_sensitive(status);
+	m_sliderScale->set_sensitive(status);
+}
+
 /*
  * Try to move the beginning of the current subtitle.
  * If the option 'respect-timing' is enabled, 
@@ -1159,12 +1173,7 @@ void WaveformEditor::on_config_waveform_changed(const Glib::ustring &key, const
 	//	m_cfg_respect_gab_between_subtitles = utility::string_to_bool(value);
 	else if(key == "display")
 	{
-		bool state = utility::string_to_bool(value);
-		
-		if(state)
-			show();
-		else
-			hide();
+		utility::string_to_bool(value) ? show() : hide();
 	}
 	else if(key == "renderer")
 	{
