@@ -24,8 +24,6 @@
  */
 
 #include <gtkmm.h>
-#include <gtkmm/scalebutton.h>
-#include <gtkmm/builder.h>
 #include "waveformrenderer.h"
 #include "player.h"
 #include "waveformmanager.h"
@@ -33,7 +31,7 @@
 /*
  *
  */
-class WaveformEditor : public WaveformManager, public Gtk::HBox
+class WaveformEditor : public WaveformManager, public Gtk::Box
 {
 public:
 
@@ -168,6 +166,9 @@ protected:
 	 */
 	bool on_scroll_event_renderer(GdkEventScroll *ev);
 
+	/*
+	 */
+	void set_child_sensitive(bool status);
 protected:
 
 	/*
@@ -344,9 +345,9 @@ protected:
 
 protected:
 	Gtk::Frame*				m_frameWaveformRenderer;
-	Gtk::HScrollbar*	m_hscrollbarWaveformRenderer;
-	Gtk::VScale*			m_sliderZoom;
-	Gtk::VScale*			m_sliderScale;
+	Gtk::Scrollbar*		m_hscrollbarWaveformRenderer;
+	Gtk::Scale*				m_sliderZoom;
+	Gtk::Scale*				m_sliderScale;
 
 	Glib::RefPtr<Waveform> m_waveform;
 	WaveformRenderer*	m_waveformRenderer;	// widget Gtk::DrawingArea
