@@ -58,6 +58,7 @@ void WaveformRenderer::init_default_config()
 	SET_COLOR(m_color_subtitle_selected, 0.9, 0.5, 0.3, 0.6);
 	SET_COLOR(m_color_subtitle_invalid, 1, 1, 0.0, 0.8); // invalid time start > end
 	SET_COLOR(m_color_text, 1, 1, 1, 1);
+	SET_COLOR(m_color_keyframe, 0.3, 0.6, 1.0, 1.0);
 
 #undef SET_COLOR
 
@@ -80,6 +81,7 @@ void WaveformRenderer::init_default_config()
 	check_color("color-subtitle-invalid", m_color_subtitle_invalid);
 	check_color("color-text", m_color_text);
 	check_color("color-player-position", m_color_player_position);
+	check_color("color-keyframe", m_color_keyframe);
 
 
 #undef check_color
@@ -105,6 +107,7 @@ void WaveformRenderer::load_config()
 	get_color("color-subtitle-invalid", m_color_subtitle_invalid);
 	get_color("color-text", m_color_text);
 	get_color("color-player-position", m_color_player_position);
+	get_color("color-keyframe", m_color_keyframe);
 
 #undef get_color
 }
@@ -127,6 +130,12 @@ void WaveformRenderer::waveform_changed()
 {
 }
 
+/*
+ */
+void WaveformRenderer::keyframes_changed()
+{
+}
+
 /*
  *
  */
@@ -173,7 +182,10 @@ long WaveformRenderer::get_time_by_pos(int pos)
  */
 int WaveformRenderer::get_pos_by_time(long msec)
 {
-	float percent = ((float)msec / (float)m_waveform->get_duration());
+	float duration = (float)m_waveform->get_duration();
+	if(duration <= 0)
+		return 0;
+	float percent = (float)msec / duration;
 	float width = (float)widget()->get_width() * zoom();
 	float pos = width * percent;
 	pos = CLAMP(pos, 0, width);
@@ -271,6 +283,10 @@ void WaveformRenderer::on_config_waveform_renderer_changed(const Glib::ustring &
 	{
 		string_to_rgba(value, m_color_player_position);
 	}
+	else if("color-keyframe" == key)
+	{
+		string_to_rgba(value, m_color_keyframe);
+	}
 
 #undef string_to_rgba
 
