@@ -23,8 +23,7 @@
  *	along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gtkmm/widget.h>
-#include <glibmm/ustring.h>
+#include <gtkmm.h>
 
 /*
  *
